@@ -588,25 +588,25 @@ Gfx8BitFont::Gfx8BitFont(XRef *xref, char *tagA, Ref idA, GString *nameA,
     if (obj2.isName("MacRomanEncoding")) {
       hasEncoding = gTrue;
       usesMacRomanEnc = gTrue;
-      baseEnc = macRomanEncoding;
+      baseEnc = const_cast<char **>(macRomanEncoding);
     } else if (obj2.isName("MacExpertEncoding")) {
       hasEncoding = gTrue;
-      baseEnc = macExpertEncoding;
+      baseEnc = const_cast<char **>(macExpertEncoding);
     } else if (obj2.isName("WinAnsiEncoding")) {
       hasEncoding = gTrue;
-      baseEnc = winAnsiEncoding;
+      baseEnc = const_cast<char **>(winAnsiEncoding);
     }
     obj2.free();
   } else if (obj1.isName("MacRomanEncoding")) {
     hasEncoding = gTrue;
     usesMacRomanEnc = gTrue;
-    baseEnc = macRomanEncoding;
+    baseEnc = const_cast<char **>(macRomanEncoding);
   } else if (obj1.isName("MacExpertEncoding")) {
     hasEncoding = gTrue;
-    baseEnc = macExpertEncoding;
+    baseEnc = const_cast<char **>(macExpertEncoding);
   } else if (obj1.isName("WinAnsiEncoding")) {
     hasEncoding = gTrue;
-    baseEnc = winAnsiEncoding;
+    baseEnc = const_cast<char **>(winAnsiEncoding);
   }
 
   // check embedded or external font file for base encoding
@@ -661,12 +661,12 @@ Gfx8BitFont::Gfx8BitFont(XRef *xref, char *tagA, Ref idA, GString *nameA,
   // get default base encoding
   if (!baseEnc) {
     if (builtinFont && embFontID.num < 0) {
-      baseEnc = builtinFont->defaultBaseEnc;
+      baseEnc = const_cast<char **>(builtinFont->defaultBaseEnc);
       hasEncoding = gTrue;
     } else if (type == fontTrueType) {
-      baseEnc = winAnsiEncoding;
+      baseEnc = const_cast<char **>(winAnsiEncoding);
     } else {
-      baseEnc = standardEncoding;
+      baseEnc = const_cast<char **>(standardEncoding);
     }
   }
 
@@ -686,7 +686,7 @@ Gfx8BitFont::Gfx8BitFont(XRef *xref, char *tagA, Ref idA, GString *nameA,
       baseEncFromFontFile) {
     for (i = 0; i < 256; ++i) {
       if (!enc[i] && standardEncoding[i]) {
-	enc[i] = standardEncoding[i];
+	enc[i] = const_cast<char *>(standardEncoding[i]);
 	encFree[i] = gFalse;
       }
     }
