@@ -65,7 +65,11 @@
 #define FC_WEIGHT_BOOK 75
 #endif
 
+#if 0
 #include "NameToUnicodeTable.h"
+#else
+#include "NameToUnicodeTableConst.h"
+#endif
 #include "UnicodeMapTables.h"
 #include "UTF8.h"
 
@@ -436,12 +440,16 @@ GlobalParams::GlobalParams(char *cfgFileName) {
   plugins = new GList();
   securityHandlers = new GList();
 #endif
-
+#if 0
   // set up the initial nameToUnicode table
   for (i = 0; nameToUnicodeTab[i].name; ++i) {
     nameToUnicode->add(nameToUnicodeTab[i].name, nameToUnicodeTab[i].u);
   }
-
+#else
+  for (unsigned int x = 0; x < NAME_TO_UNICODE_TAB_LENGTH; ++x) {
+    nameToUnicode->add(nameToUnicodeTabString + nameToUnicodeTabConst[x].offs, nameToUnicodeTabConst[x].u); 
+  }
+#endif
   // set up the residentUnicodeMaps table
   map = new UnicodeMap("Latin1", gFalse,
 		       latin1UnicodeMapRanges, latin1UnicodeMapLen);
